@@ -39,7 +39,6 @@ class Metering:
         if Metering.__instance is not None:
             raise Exception("Metering " + config_messages.SINGLETON_EXCEPTION)
         self.__metering_url = None
-        self.__apikey = None
         self.__repeating = True
         self.__lock = Lock()
         self.__metering_feature_data = dict()
@@ -55,15 +54,13 @@ class Metering:
         """
         self.__repeating = repeat
 
-    def set_metering_url(self, url: str, apikey):
+    def set_metering_url(self, url: str):
         """Set the metering url
 
         Args:
             url: Url for the metering.
-            apikey: Api Key of the service.
         """
         self.__metering_url = url
-        self.__apikey = apikey
 
     def add_metering(self, guid: str, environment_id: str,
                      collection_id: str, entity_id: str,
@@ -149,13 +146,26 @@ class Metering:
     def __send_to_server(self, guid, data):
         if self.__repeating:
             api_manager = APIManager.get_instance()
-            api_manager.setup_base()
             response = api_manager.prepare_api_request(method="POST",
-                                                   url="{0}{1}/usage".format(self.__metering_url, guid),
-                                                   data=data)
+                                                       url="{0}{1}/usage".format(self.__metering_url, guid),
+                                                       data=data)
             status_code = response.get_status_code()
-            if 200 <= status_code <= 299:
-                Logger.debug("Posted metering data successfully")
+            if status_code == 202:
+                Logger.info("Successfully posted metering data")
+            else:
+                Logger.error(f'Failed to send the metering data. Reason - {response.get_result()}')
+                """schedule a function to send the same payload after 10 minutes"""
+                if status_code is None:
+                    """
+                    status_code will be None in-case of
+
+                        1. request was retried for [429, 500, 502, 503, 504] status codes which has exceeded the retry count and has raised the exception "requests.exceptions.RetryError".
+                        Check api_manager.py for more info.
+                        2. request failed due to unknown "Exception".
+                    """
+                    retry_metering = Timer(self.__send_interval, self.__send_to_server, args=(guid, data))
+                    retry_metering.daemon = True
+                    retry_metering.start()
 
     def __build_request_body(self, send_metering_data: dict, result: dict, main_key: str):
 
@@ -211,7 +221,7 @@ class Metering:
         for guid, values in result.items():
             for data in values:
                 count = len(data['usages'])
-                if count > 25:
+                if count > config_constants.DEFAULT_USAGE_LIMIT:
                     self.__send_split_metering(guid, data, count)
                 else:
                     self.__send_to_server(guid=guid, data=data)
@@ -219,11 +229,11 @@ class Metering:
 
     def __send_split_metering(self, guid: str, data: dict, count: int):
         limit = 0
-        while limit <= count:
+        while limit < count:
             collections_map = {
                 'collection_id': data['collection_id'],
                 'environment_id': data['environment_id'],
-                'usages': data['usages'][limit:limit+25]
+                'usages': data['usages'][limit:limit + config_constants.DEFAULT_USAGE_LIMIT]
             }
             self.__send_to_server(guid=guid, data=collections_map)
-            limit += 25
+            limit += config_constants.DEFAULT_USAGE_LIMIT
